.. fedsim documentation master file, created by
   sphinx-quickstart on Tue Jun 14 23:06:19 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


FedSim
======

.. include:: readme.rst
.. include:: installation.rst
.. include:: demo.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   notebooks/tutorial
   modules
   customization
   contributing
   authors
   changelog

